[libdvdcss-devel] Rename win_readv() to win2k_readv for consistency.

[email protected] (Diego Biurrun)
Newsgroups gmane.comp.video.videolan.libdvdcss,gmane.comp.video.videolan.libdvdcss.devel
Message-ID <[email protected]>
libdvdcss | branch: master | Diego Biurrun <[email protected]> | Fri Oct 24 11:13:44 2014 +0200| [0d571b2cded0028dbbdac5104555ff334cfb860c] | committer: Diego Biurrun

Rename win_readv() to win2k_readv for consistency.

> http://git.videolan.org/gitweb.cgi/libdvdcss.git/?a=commit;h=0d571b2cded0028dbbdac5104555ff334cfb860c
---

 src/device.c |   14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/src/device.c b/src/device.c
index 7ed2cc5..1a060e6 100644
--- a/src/device.c
+++ b/src/device.c
@@ -83,10 +83,10 @@ static int libc_read  ( dvdcss_t, void *, int );
 static int libc_readv ( dvdcss_t, struct iovec *, int );
 
 #ifdef WIN32
-static int win2k_open ( dvdcss_t, const char * );
-static int win2k_seek ( dvdcss_t, int );
-static int win2k_read ( dvdcss_t, void *, int );
-static int win_readv  ( dvdcss_t, struct iovec *, int );
+static int win2k_open  ( dvdcss_t, const char * );
+static int win2k_seek  ( dvdcss_t, int );
+static int win2k_read  ( dvdcss_t, void *, int );
+static int win2k_readv ( dvdcss_t, struct iovec *, int );
 
 #elif defined( __OS2__ )
 static int os2_open ( dvdcss_t, const char * );
@@ -363,7 +363,7 @@ int dvdcss_open_device ( dvdcss_t dvdcss )
         print_debug( dvdcss, "using Win2K API for access" );
         dvdcss->pf_seek  = win2k_seek;
         dvdcss->pf_read  = win2k_read;
-        dvdcss->pf_readv = win_readv;
+        dvdcss->pf_readv = win2k_readv;
         return win2k_open( dvdcss, psz_device );
     }
     else
@@ -724,9 +724,9 @@ static int libc_readv ( dvdcss_t dvdcss, struct iovec *p_iovec, int i_blocks )
 
 #if defined( WIN32 )
 /*****************************************************************************
  * win_readv: vectored read using ReadFile for Win2K
  *****************************************************************************/
-static int win_readv ( dvdcss_t dvdcss, struct iovec *p_iovec, int i_blocks )
+static int win2k_readv ( dvdcss_t dvdcss, struct iovec *p_iovec, int i_blocks )
 {
     int i_index;
     int i_blocks_read, i_blocks_total = 0;
@@ -724,9 +724,9 @@ static int libc_readv ( dvdcss_t dvdcss, struct iovec *p_iovec, int i_blocks )
 #if defined( WIN32 )
 /*****************************************************************************
- * win_readv: vectored read using ReadFile for Win2K
+ * win2k_readv: vectored read using ReadFile for Win2K
  *****************************************************************************/

_______________________________________________
libdvdcss-devel mailing list
[email protected]
https://mailman.videolan.org/listinfo/libdvdcss-devel
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.